@@ -20,14 +20,10 @@ from pecan import hooks
 from aodh.api import policies
 
 # TODO(gmann): Remove overriding the default value of config options:
-# - 'policy_file' once oslo_policy change their default value to what is
-# overridden here.
 # - 'enforce_scope', and 'enforce_new_defaults' once aodh is ready with the
 # new RBAC (oslo_policy enable them by default)
-DEFAULT_POLICY_FILE = 'policy.yaml'
 opts.set_defaults(
     cfg.CONF,
-    DEFAULT_POLICY_FILE,
     enforce_scope=False,
     enforce_new_defaults=False)
 
