@@ -17,44 +17,40 @@
 
 """Access Control Lists (ACL's) control access the API server."""
 
+from oslo_context import context
 import pecan
 
 
-def target_from_segregation_rule(headers, enforcer):
+def target_from_segregation_rule(req, enforcer):
     """Return a target corresponding to an alarm returned by segregation rule
 
     This allows to use project_id: in an oslo_policy rule for query/listing.
 
-    :param headers: HTTP headers dictionary
+    :param req: Webob Request object
     :param enforcer: policy enforcer
 
     :returns: target
     """
 
-    project_id = get_limited_to_project(headers, enforcer)
+    project_id = get_limited_to_project(req, enforcer)
     if project_id is not None:
         return {'project_id': project_id}
     return {}
 
 
-def enforce(policy_name, headers, enforcer, target):
+def enforce(policy_name, req, enforcer, target):
     """Return the user and project the request should be limited to.
 
     :param policy_name: the policy name to validate authz against.
-    :param headers: HTTP headers dictionary
+    :param req: Webob Request object
     :param enforcer: policy enforcer
     :param target: the alarm or "auto" to
 
     """
     rule_method = "telemetry:" + policy_name
+    ctxt = context.RequestContext.from_environ(req.environ)
 
-    credentials = {
-        'roles': headers.get('X-Roles', "").split(","),
-        'user_id': headers.get('X-User-Id'),
-        'project_id': headers.get('X-Project-Id'),
-    }
-
-    if not enforcer.enforce(rule_method, target, credentials):
+    if not enforcer.enforce(rule_method, target, ctxt.to_dict()):
         pecan.core.abort(status_code=403,
                          detail='RBAC Authorization Failed')
 
@@ -62,43 +58,33 @@ def enforce(policy_name, headers, enforcer, target):
 # TODO(fabiog): these methods are still used because the scoping part is really
 # convoluted and difficult to separate out.
 
-def get_limited_to(headers, enforcer):
+def get_limited_to(req, enforcer):
     """Return the user and project the request should be limited to.
 
-    :param headers: HTTP headers dictionary
+    :param req: Webob Request object
     :param enforcer: policy enforcer
     :return: A tuple of (user, project), set to None if there's no limit on
     one of these.
 
     """
-    # TODO(sileht): Only filtering on role work currently for segregation
-    # oslo.policy expects the target to be the alarm. That will allow
-    # creating more enhanced rbac. But for now we enforce the
-    # scoping of request to the project-id, so...
-    target = {}
-    credentials = {
-        'roles': headers.get('X-Roles', "").split(","),
-    }
-    # maintain backward compat with Juno and previous by using context_is_admin
-    # rule if the segregation rule (added in Kilo) is not defined
-    rules = enforcer.rules.keys()
-    rule_name = 'segregation' if 'segregation' in rules else 'context_is_admin'
-    if not enforcer.enforce(rule_name, target, credentials):
-        return headers.get('X-User-Id'), headers.get('X-Project-Id')
+    ctxt = context.RequestContext.from_environ(req.environ)
+    if not enforcer.enforce('segregation', {}, ctxt.to_dict()):
+        return ctxt.user_id, ctxt.project_id
 
     return None, None
 
 
-def get_limited_to_project(headers, enforcer):
+def get_limited_to_project(req, enforcer):
     """Return the project the request should be limited to.
 
-    :param headers: HTTP headers dictionary
+    :param req: Webob Request object
     :param enforcer: policy enforcer
     :return: A project, or None if there's no limit on it.
 
     """
-    return get_limited_to(headers, enforcer)[1]
+    return get_limited_to(req, enforcer)[1]
 
 
-def is_admin(headers):
-    return 'admin' in headers.get('X-Roles', "").split(",")
+def is_admin(req, enforcer):
+    ctxt = context.RequestContext.from_environ(req.environ)
+    return enforcer.enforce('context_is_admin', {}, ctxt.to_dict())
