@@ -12,12 +12,12 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import fnmatch
 import json
 import operator
 
 from oslo_config import cfg
 from oslo_log import log
-from oslo_utils import fnmatch
 from oslo_utils import timeutils
 
 from aodh import evaluator
