@@ -22,7 +22,7 @@ from oslo_config import fixture as fixture_config
 
 import oslo_messaging
 import requests
-import six.moves.urllib.parse as urlparse
+from urllib import parse as urlparse
 
 from aodh import keystone_client
 from aodh import notifier
