@@ -20,24 +20,6 @@ else
     AODH_BIN_DIR=$(get_python_exec_prefix)
 fi
 
-
-if [ -z "$AODH_DEPLOY" ]; then
-    # Default
-    AODH_DEPLOY=simple
-
-    # Fallback to common wsgi devstack configuration
-    if [ "$ENABLE_HTTPD_MOD_WSGI_SERVICES" == "True" ]; then
-        AODH_DEPLOY=mod_wsgi
-
-    # Deprecated config
-    elif [ -n "$AODH_USE_MOD_WSGI" ] ; then
-        echo_summary "AODH_USE_MOD_WSGI is deprecated, use AODH_DEPLOY instead"
-        if [ "$AODH_USE_MOD_WSGI" == True ]; then
-            AODH_DEPLOY=mod_wsgi
-        fi
-    fi
-fi
-
 # Test if any Aodh services are enabled
 # is_aodh_enabled
 function is_aodh_enabled {
@@ -178,7 +160,7 @@ function configure_aodh {
     iniset $AODH_CONF service_credentials region_name $REGION_NAME
     iniset $AODH_CONF service_credentials auth_url $KEYSTONE_SERVICE_URI
 
-    configure_auth_token_middleware $AODH_CONF aodh $AODH_AUTH_CACHE_DIR
+    configure_keystone_authtoken_middleware $AODH_CONF aodh
 
     # Configured storage
     _aodh_configure_storage_backend
@@ -219,9 +201,6 @@ function configure_aodh {
 function init_aodh {
     # Get aodh keystone settings in place
     _aodh_create_accounts
-    # Create cache dir
-    sudo install -d -o $STACK_USER $AODH_AUTH_CACHE_DIR
-    rm -f $AODH_AUTH_CACHE_DIR/*
 
     if is_service_enabled mysql postgresql; then
         if [ "$AODH_BACKEND" = 'mysql' ] || [ "$AODH_BACKEND" = 'postgresql' ] ; then
@@ -239,7 +218,7 @@ function init_aodh {
 function install_aodh {
     _aodh_prepare_coordination
     install_aodhclient
-    pip_install -e "$AODH_DIR"[test,$AODH_BACKEND]
+    setup_develop $AODH_DIR $AODH_BACKEND
     sudo install -d -o $STACK_USER -m 755 $AODH_CONF_DIR
 
     if [ "$AODH_DEPLOY" == "mod_wsgi" ]; then
